@@ -1,7 +1,7 @@
 context("test multistar_as_flat_table")
 
 test_that("multistar_as_flat_table works", {
-  ft <- ms_mrs_test %>%
+  ft <- ms_mrs_test |>
     multistar_as_flat_table(fact = "mrs_age")
 
   expect_equal(
@@ -23,21 +23,21 @@ test_that("multistar_as_flat_table works", {
   )
   expect_equal(length(ft[[1]]), 24)
 
-  ms <- dimensional_query(ms_mrs_test) %>%
+  ms <- dimensional_query(ms_mrs_test) |>
     select_dimension(name = "where",
-                     attributes = c("city", "state")) %>%
+                     attributes = c("city", "state")) |>
     select_dimension(name = "when",
-                     attributes = c("year", "week")) %>%
+                     attributes = c("year", "week")) |>
     select_fact(
       name = "mrs_age",
       measures = c("deaths")
-    ) %>%
+    ) |>
     select_fact(
       name = "mrs_cause",
       measures = c("pneumonia_and_influenza_deaths", "other_deaths")
-    ) %>%
+    ) |>
     run_query()
-  ft <- ms %>%
+  ft <- ms |>
     multistar_as_flat_table()
 
   expect_equal(
@@ -49,8 +49,8 @@ test_that("multistar_as_flat_table works", {
       "state",
       "deaths",
       "nrow_agg",
-      "pneumonia_and_influenza_deaths",
-      "other_deaths",
+      "mrs_cause_pneumonia_and_influenza_deaths",
+      "mrs_cause_other_deaths",
       "mrs_cause_nrow_agg"
     )
   )
