@@ -2,7 +2,7 @@ context("test rename_measures")
 
 test_that("rename_measures works", {
   st <-
-    st_mrs_age_test %>%
+    st_mrs_age_test |>
     rename_measures(measures = c("deaths", "nrow_agg"),
                     new_names = c("n_deaths", "n_agg"))
 
